@@ -503,8 +503,8 @@ def get_list_compreh_part_fragment(content):
             return code_pair_list
 
     except:
-        traceback.print_exc()
-        code_pair_list=["syntax error in code"]
+        # traceback.print_exc()
+        # code_pair_list=["syntax error in code"]
         return code_pair_list
 
 
