@@ -607,20 +607,95 @@ def transform_for_else_code(content):
                 old_code_5_content = ast.get_source_segment(content, code[5])
                 old_code_3_content = ast.get_source_segment(content, code[3])
                 old_code_6_content = ast.get_source_segment(content, code[6])
+                old_node_space_prefix=old_code_3_content.split('\n')[1]
+
+                new_code_fragment_list=ast.unparse(code[4]).split('\n')
+                for ind,e_fragment in enumerate(new_code_fragment_list):
+                    if ind>0:
+                        new_code_fragment_list[ind] = ' ' * code[3].col_offset + e_fragment
+
                 if code[7]:
                     line_list=[[(code[5].lineno,code[5].col_offset), (code[5].end_lineno,code[5].end_col_offset)]]
                     line_list.append([(code[3].lineno,code[3].col_offset), (code[3].end_lineno,code[3].end_col_offset)])
                     line_list.append([(code[6].lineno,code[6].col_offset), (code[6].end_lineno,code[6].end_col_offset)])
 
 
-                    code_pair_list.append([class_name,me_name,[old_code_5_content,old_code_3_content,old_code_6_content],  ['',ast.unparse(code[4]),''],line_list])
+                    # code_pair_list.append([class_name,me_name,[old_code_5_content,old_code_3_content,old_code_6_content],  ['',ast.unparse(code[4]),''],line_list])
+                    code_pair_list.append([class_name,me_name,[old_code_5_content,old_code_3_content,old_code_6_content],  ['',"\n".join(new_code_fragment_list),''],line_list])
+
                 else:
                     line_list = []
                     line_list.append(
                         [(code[3].lineno, code[3].col_offset), (code[3].end_lineno, code[3].end_col_offset)])
                     line_list.append(
                         [(code[6].lineno, code[6].col_offset), (code[6].end_lineno, code[6].end_col_offset)])
-                    code_pair_list.append([class_name,me_name,[old_code_3_content,old_code_6_content], [ast.unparse(code[5]),ast.unparse(code[4])],line_list])
+                    # code_pair_list.append([class_name,me_name,[old_code_3_content,old_code_6_content], [ast.unparse(code[5]),ast.unparse(code[4])],line_list])
+                    code_pair_list.append([class_name,me_name,[old_code_3_content,old_code_6_content], ["\n".join(new_code_fragment_list),''],line_list])
+
+                # code_pair_list.append([class_name, me_name,
+                #                        ast.unparse(code[5]) + "\n" + ast.unparse(code[3]) + "\n" + ast.unparse(code[6]),
+                #                        ast.unparse(code[4]) if code[7] else ast.unparse(code[5]) + "\n" + ast.unparse(
+                #                            code[4]), line_list])
+
+        return code_pair_list
+
+    except:
+        traceback.print_exc()
+        return code_pair_list
+
+def transform_part_for_else_code(content):
+    code_pair_list = []
+    # print(content)
+    try:
+
+
+        tree = ast.parse(content)
+        if 1:
+        # for tree, class_name in ana_py.func_def_list:
+            try:
+                me_name=tree.name
+            except:
+                me_name=""
+            new_code_list = []
+            ass_init_list = []
+            traverse_cur_layer(tree, new_code_list, ass_init_list)
+            # #result_compli_for_else_list.append(
+            #                     [repo_name, file_html, cl,me,code[3].lineno,ast.unparse(code[5])+"\n"+ast.unparse(code[3])+"\n"+ast.unparse(code[6]), ast.unparse(code[4]),code[7]])
+
+                # new_file_content = replace_file_content_ass(content, each_assign_list, new_code)
+                # assign_list[ind_ass].append(new_code)
+                # complic_code_me_info_dir_pkl = util.data_root + "complic_code_me_info_dir_pkl/each_idiom_type_all_methods/multi_ass/"  # for_else
+                # util.save_file(complic_code_me_info_dir_pkl, "test"+str(ind_ass), new_file_content, ".txt", "w")
+                # util.save_file(complic_code_me_info_dir_pkl, "test_old"+str(ind_ass), content, ".txt", "w")
+            for code in new_code_list:
+                old_code_5_content = ast.get_source_segment(content, code[5])
+                old_code_3_content = ast.get_source_segment(content, code[3])
+                old_code_6_content = ast.get_source_segment(content, code[6])
+                old_node_space_prefix=old_code_3_content.split('\n')[1]
+
+                new_code_fragment_list=ast.unparse(code[4]).split('\n')
+                for ind,e_fragment in enumerate(new_code_fragment_list):
+                    if ind>0:
+                        new_code_fragment_list[ind] = ' ' * code[3].col_offset + e_fragment
+
+                if code[7]:
+                    line_list=[[(code[5].lineno,code[5].col_offset), (code[5].end_lineno,code[5].end_col_offset)]]
+                    line_list.append([(code[3].lineno,code[3].col_offset), (code[3].end_lineno,code[3].end_col_offset)])
+                    line_list.append([(code[6].lineno,code[6].col_offset), (code[6].end_lineno,code[6].end_col_offset)])
+
+
+                    # code_pair_list.append([class_name,me_name,[old_code_5_content,old_code_3_content,old_code_6_content],  ['',ast.unparse(code[4]),''],line_list])
+                    code_pair_list.append(['',me_name,[old_code_5_content,old_code_3_content,old_code_6_content],  ['',"\n".join(new_code_fragment_list),''],line_list])
+
+                else:
+                    line_list = []
+                    line_list.append(
+                        [(code[3].lineno, code[3].col_offset), (code[3].end_lineno, code[3].end_col_offset)])
+                    line_list.append(
+                        [(code[6].lineno, code[6].col_offset), (code[6].end_lineno, code[6].end_col_offset)])
+                    # code_pair_list.append([class_name,me_name,[old_code_3_content,old_code_6_content], [ast.unparse(code[5]),ast.unparse(code[4])],line_list])
+                    code_pair_list.append(['',me_name,[old_code_3_content,old_code_6_content], ["\n".join(new_code_fragment_list),''],line_list])
+
                 # code_pair_list.append([class_name, me_name,
                 #                        ast.unparse(code[5]) + "\n" + ast.unparse(code[3]) + "\n" + ast.unparse(code[6]),
                 #                        ast.unparse(code[4]) if code[7] else ast.unparse(code[5]) + "\n" + ast.unparse(
