@@ -525,7 +525,7 @@ def main(args):
                         for ind_save,each_code_pair in enumerate(each_file_code_list):
                             new_content=file_replace(abs_path,[each_code_pair])
                             # print(">>>>>output_dir: ", output_dir,save_dir)
-                            util.save_file_path("".join([output_dir,save_dir,"/",file_name[:-3],'_',str(ind_save),'.py']),new_content)
+                            util.save_file_path("".join([output_dir,save_dir,"/",file_name[:-3],'_',str(ind_save+len(format_code_list)),'.py']),new_content)
 
                     else:
                         new_content=file_replace(abs_path,each_file_code_list)
@@ -575,12 +575,12 @@ if __name__ == '__main__':
     parser = argparse.ArgumentParser(description='RefactoringIdioms')
     parser.add_argument('--envname', type=str,
                         help='envname', default="CartPole-v0")
-    parser.add_argument('--filepath', type=str,
-                        help='filepath', default=abs_path+"/file.py")
+    # parser.add_argument('--filepath', type=str,
+    #                     help='filepath', default=abs_path+"/file.py")
     # parser.add_argument('--filepath', type=str,
     #                     help='filepath', default=abs_path + "/")
-    # parser.add_argument('--filepath', type=str,
-    #                     help='filepath', default= "./")
+    parser.add_argument('--filepath', type=str,
+                        help='filepath', default= "./")
     # parser.add_argument('--filepath', type=str,
     #                     help='filepath', default="/Users/zhangzejunzhangzejun/PycharmProjects/code")
     #
